==> haskell-x509-system-1.6.6-240-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-system
version:              1.6.6
visibility:           public
id:                   x509-system-1.6.6-Fp4NL18jBDD6uZdxyAFfwd
key:                  x509-system-1.6.6-Fp4NL18jBDD6uZdxyAFfwd
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:          System X.509 handling
category:             Data
abi:                  77b3d1a6d4294a142c676303cd8c40c1
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-system-1.6.6
hs-libraries:         HSx509-system-1.6.6-Fp4NL18jBDD6uZdxyAFfwd
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-KLN0tuS3ZoG84EBMFRxUqE process-1.6.11.0
    x509-1.7.5-KZBg6E9cDNpzkDdONM3tO
    x509-store-1.6.7-GjMuzyM4405JwkexKUzc5E

haddock-interfaces:   /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html:         /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-system-1.6.6-241-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-system
version:              1.6.6
visibility:           public
id:                   x509-system-1.6.6-9IGmtFMLqYr65UwYvJv3DD
key:                  x509-system-1.6.6-9IGmtFMLqYr65UwYvJv3DD
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:          System X.509 handling
category:             Data
abi:                  19a3b1877ebd5766d63f6414bcc60aca
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-system-1.6.6
hs-libraries:         HSx509-system-1.6.6-9IGmtFMLqYr65UwYvJv3DD
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-HYg3Jt06Zqq3C6bOo96L1R process-1.6.11.0
    x509-1.7.5-HyBJj96t9GC2vaOmQQ4ozv
    x509-store-1.6.7-E1M1yu7n5ys7g0MI3dEOO3

haddock-interfaces:   /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html:         /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
